@@ -4,7 +4,6 @@ import (
 	"context"
 	"fmt"
 	"image"
-	"strings"
 
 	"github.com/derailed/k9s/internal"
 	"github.com/derailed/k9s/internal/client"
@@ -16,6 +15,8 @@ import (
 	"github.com/derailed/k9s/internal/ui"
 	"github.com/derailed/tview"
 	"github.com/gdamore/tcell/v2"
+	"golang.org/x/text/cases"
+	"golang.org/x/text/language"
 )
 
 // Graphable represents a graphic component.
@@ -162,7 +163,7 @@ func (p *Pulse) PulseChanged(c *health.Check) {
 	case "cpu":
 		perc := client.ToPercentage(c.Tally(health.S1), c.Tally(health.S2))
 		v.SetLegend(fmt.Sprintf(cpuFmt,
-			strings.Title(gvr.R()),
+			cases.Title(language.Und, cases.NoLower).String(gvr.R()),
 			p.app.Config.K9s.Thresholds.SeverityColor("cpu", perc),
 			render.PrintPerc(perc),
 			nn[0],
@@ -173,7 +174,7 @@ func (p *Pulse) PulseChanged(c *health.Check) {
 	case "mem":
 		perc := client.ToPercentage(c.Tally(health.S1), c.Tally(health.S2))
 		v.SetLegend(fmt.Sprintf(memFmt,
-			strings.Title(gvr.R()),
+			cases.Title(language.Und, cases.NoLower).String(gvr.R()),
 			p.app.Config.K9s.Thresholds.SeverityColor("memory", perc),
 			render.PrintPerc(perc),
 			nn[0],
@@ -183,7 +184,7 @@ func (p *Pulse) PulseChanged(c *health.Check) {
 		))
 	default:
 		v.SetLegend(fmt.Sprintf(genFmat,
-			strings.Title(gvr.R()),
+			cases.Title(language.Und, cases.NoLower).String(gvr.R()),
 			nn[0],
 			c.Tally(health.S1),
 			nn[1],
@@ -206,7 +207,7 @@ func (p *Pulse) bindKeys() {
 	})
 
 	for i, v := range p.charts {
-		t := strings.Title(client.NewGVR(v.ID()).R())
+		t := cases.Title(language.Und, cases.NoLower).String(client.NewGVR(v.ID()).R())
 		p.actions[tcell.Key(ui.NumKeys[i])] = ui.NewKeyAction(t, p.sparkFocusCmd(i), true)
 	}
 }
@@ -340,7 +341,7 @@ func (p *Pulse) makeSP(loc image.Point, span image.Point, gvr string) *tchart.Sp
 	} else {
 		s.SetSeriesColors(p.app.Styles.Charts().DefaultChartColors.Colors()...)
 	}
-	s.SetLegend(fmt.Sprintf(" %s ", strings.Title(client.NewGVR(gvr).R())))
+	s.SetLegend(fmt.Sprintf(" %s ", cases.Title(language.Und, cases.NoLower).String(client.NewGVR(gvr).R())))
 	s.SetInputCapture(p.keyboard)
 	s.SetMultiSeries(true)
 	p.AddItem(s, loc.X, loc.Y, span.X, span.Y, 0, 0, true)
@@ -358,7 +359,7 @@ func (p *Pulse) makeGA(loc image.Point, span image.Point, gvr string) *tchart.Ga
 	} else {
 		g.SetSeriesColors(p.app.Styles.Charts().DefaultDialColors.Colors()...)
 	}
-	g.SetLegend(fmt.Sprintf(" %s ", strings.Title(client.NewGVR(gvr).R())))
+	g.SetLegend(fmt.Sprintf(" %s ", cases.Title(language.Und, cases.NoLower).String(client.NewGVR(gvr).R())))
 	g.SetInputCapture(p.keyboard)
 	p.AddItem(g, loc.X, loc.Y, span.X, span.Y, 0, 0, true)
 
