@@ -8,7 +8,6 @@ import (
 	"github.com/derailed/k9s/internal"
 	"github.com/derailed/k9s/internal/client"
 	"github.com/derailed/k9s/internal/config"
-	"github.com/derailed/k9s/internal/render"
 	"github.com/derailed/k9s/internal/ui"
 	"github.com/gdamore/tcell/v2"
 	"github.com/rs/zerolog/log"
@@ -26,7 +25,6 @@ func NewScreenDump(gvr client.GVR) ResourceViewer {
 	}
 	s.GetTable().SetBorderFocusColor(tcell.ColorSteelBlue)
 	s.GetTable().SetSelectedStyle(tcell.StyleDefault.Foreground(tcell.ColorWhite).Background(tcell.ColorRoyalBlue).Attributes(tcell.AttrNone))
-	s.GetTable().SetColorerFn(render.ScreenDump{}.ColorerFunc())
 	s.GetTable().SetSortCol(ageCol, true)
 	s.GetTable().SelectRow(1, true)
 	s.GetTable().SetEnterFn(s.edit)
